==> portal-transparencia-2.120.0.zip: BOOT-INF/classes/db/sql/contab/veiculo-gastos-por-data-gasto.sql <==
SELECT A.ENTIDADE, A.MES,  A.MANUTENCAO, A.ABASTECIMENTO, A.PNEUS, A.BATERIAS, A.TOTALGERAL,
       t.DESCRICAO AS COMBUSTIVELDESCRICAO,
       ((SELECT MIN(COALESCE(CASE WHEN MM.KMANTERIOR < GP1.KMANTERIOR THEN MM.KMANTERIOR ELSE GP1.KMANTERIOR END, 0))
                    FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1 left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) =  EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMANTERIOR,0) > 0)) KMANTERIOR,
                 COALESCE((SELECT MAX(COALESCE(CASE WHEN MM.KMATUAL > GP1.KMATUAL THEN MM.KMATUAL ELSE GP1.KMATUAL END, 0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1  left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) = EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMATUAL,0) > 0),0) KMATUAL,
        CASE
          when ( (COALESCE((SELECT MIN(COALESCE(GP1.KMANTERIOR,0)) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMANTERIOR,0) > 0),0) >= 0) AND
            COALESCE((SELECT MAX(COALESCE(mm.kmatual ,GP1.KMATUAL,0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1  left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) = EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMATUAL,0) >0 ),0) >= 0) THEN
                     ((COALESCE((SELECT MAX(COALESCE(CASE WHEN MM.KMATUAL > GP1.KMATUAL THEN MM.KMATUAL ELSE GP1.KMATUAL END, 0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1  left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) = EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMATUAL,0) > 0),0))  -
                    (SELECT MIN(COALESCE(CASE WHEN MM.KMANTERIOR < GP1.KMANTERIOR THEN MM.KMANTERIOR ELSE GP1.KMANTERIOR END, 0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1 left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) =EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMANTERIOR,0) > 0))
        else 0
        END KMPERCORRIDO,
        A.OBSERVACAO
FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL_DATAGASTO A left JOIN ${db.contabilidade.schema}.pat_veiculo v on a.entidade = v.entidade
                                                          and a.veiculo = v.bem
                                  LEFT JOIN ${db.contabilidade.schema}.pat_tipocombustivel t on v.tipocombustivel = t.tipocombustivel
WHERE A.ENTIDADE = :entidade
  AND A.EXERCICIO = :exercicio
  AND A.VEICULO = :veiculo
ORDER BY A.MES

==> portal-transparencia-2.145.0.zip: BOOT-INF/classes/db/sql/contab/veiculo-gastos-por-data-gasto.sql <==
SELECT A.ENTIDADE, A.MES,  A.MANUTENCAO, A.ABASTECIMENTO, A.PNEUS, A.BATERIAS, A.TOTALGERAL,
       t.DESCRICAO AS COMBUSTIVELDESCRICAO,
       ((SELECT MIN(COALESCE(CASE WHEN MM.KMANTERIOR < GP1.KMANTERIOR THEN MM.KMANTERIOR ELSE GP1.KMANTERIOR END, 0))
                    FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1 left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) =  EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMANTERIOR,0) > 0)) KMANTERIOR,
                 COALESCE((SELECT MAX(COALESCE(CASE WHEN MM.KMATUAL > GP1.KMATUAL THEN MM.KMATUAL ELSE GP1.KMATUAL END, 0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1  left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) = EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMATUAL,0) > 0),0) KMATUAL,
        CASE
          when ( (COALESCE((SELECT MIN(COALESCE(GP1.KMANTERIOR,0)) FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMANTERIOR,0) > 0),0) >= 0) AND
            COALESCE((SELECT MAX(COALESCE(mm.kmatual ,GP1.KMATUAL,0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1  left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) = EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMATUAL,0) >0 ),0) >= 0) THEN
                     ((COALESCE((SELECT MAX(COALESCE(CASE WHEN MM.KMATUAL > GP1.KMATUAL THEN MM.KMATUAL ELSE GP1.KMATUAL END, 0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1  left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) = EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMATUAL,0) > 0),0))  -
                    (SELECT MIN(COALESCE(CASE WHEN MM.KMANTERIOR < GP1.KMANTERIOR THEN MM.KMANTERIOR ELSE GP1.KMANTERIOR END, 0))
                             FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL GP1 left JOIN ${db.contabilidade.schema}.fr_movimentomedidor mm on gp1.entidade_bem = mm.entidade
                                                                              and gp1.exercicio  = mm.exercicio
                                                                              and gp1.veiculo  = mm.veiculo
                                                                              and extract(month from mm.data) =EXTRACT(MONTH FROM GP1.DATAGASTO)
                             WHERE GP1.ENTIDADE = A.ENTIDADE
                               AND GP1.EXERCICIO = A.EXERCICIO
                               AND GP1.VEICULO = A.VEICULO
                               AND EXTRACT(MONTH FROM GP1.DATAGASTO) = A.MES
                               AND GP1.TIPOITEMMA = 'A'
                               AND COALESCE(GP1.KMANTERIOR,0) > 0))
        else 0
        END KMPERCORRIDO,
        A.OBSERVACAO
FROM ${db.contabilidade.schema}.FR_GASTOS_PORTAL_DATAGASTO A
INNER JOIN ${db.contabilidade.schema}.PAT_BEM B ON B.ENTIDADE = A.ENTIDADE_BEM
                                               AND B.TIPO = 'V'
                                               AND B.BEM = A.VEICULO
LEFT JOIN ${db.contabilidade.schema}.PAT_VEICULO V ON A.ENTIDADE = V.ENTIDADE
                                                  AND A.VEICULO = V.BEM
LEFT JOIN ${db.contabilidade.schema}.PAT_TIPOCOMBUSTIVEL T ON V.TIPOCOMBUSTIVEL = T.TIPOCOMBUSTIVEL
WHERE A.ENTIDADE_BEM = :entidade
  AND (A.ENTIDADE = :entidade OR B.COMPARTILHA_ENTSN = 'S')
  AND A.EXERCICIO = :exercicio
  AND A.VEICULO = :veiculo
ORDER BY A.MES
